@@ -151,12 +151,12 @@ def setup(**settings_patches):
     # Make beanstalk access ssh
     print section_title('Configure SSH server')
     sshd_config = '/etc/ssh/sshd_config'
-    new_lines = [
-        'Match Group beanstalk',
-        '       ForceCommand /usr/bin/bs_ssh_entry',
-    ]
-    local(sed('$ a\\\n{command}'.format(command='\\n'.join(new_lines)), sshd_config))
-    local(sed('s/^AllowGroups (.*)$/AllowGroups \\1 beanstalk/g', sshd_config, '-E'))
+    #new_lines = [
+    #    'Match Group beanstalk',
+    #    '       ForceCommand /usr/bin/bs_ssh_entry',
+    #]
+    #local(sed('$ a\\\n{command}'.format(command='\\n'.join(new_lines)), sshd_config))
+    local(sed('/^AllowGroups wheel$/cAllowGroups wheel beanstalk', sshd_config))  # TODO: More general form
 
     # Apache conf
     print section_title('Configure Apache HTTP server')
@@ -366,6 +366,10 @@ def install_app(project_name, **settings_patches):
         uid = local('id -u beanstalk', capture=True)
     config.set('uwsgi', 'uid', uid)
     config.set('uwsgi', 'logto', os.path.join(project_logs_path(project_name), 'uwsgi.log'))
+    config.remove_option('uwsgi', 'http')
+    config.remove_option('uwsgi', 'https')
+    config.remove_option('uwsgi', 'http-proxy')
+    config.remove_option('uwsgi', 'http-to')
     with open(uwsgi_path, 'wb') as f:
         config.write(f)
 
@@ -533,22 +537,3 @@ def add_user(tmp_key_path, clean_tmp_key=False):
         local('rm -rf {path}'.format(path=tmp_key_path))
 
     print green('User added.')
-
-
-@task
-@beanstalk_role('server')
-def run_app_command(project_name, command, location='source'):
-    """Run a remote command
-    """
-    print command
-#    if location == 'base':
-#        path = project_base_path(project_name)
-#    elif location == 'logs':
-#        path = project_logs_path(project_name)
-#    else:
-#        path = project_source_path(project_name)
-#
-#    venv_path = project_venv_path(project_name)
-#
-#    with settings(lcd(path), virtual_env(venv_path)):
-#        local(command)
